==> fwobac-1.2.tar.gz: fwobac-1.2/aabc.h <==
/* $Id: aabc.h,v 1.4 2017/08/05 11:31:45 rlr Exp rlr $ */

/*
 * Copyright (c) 2016 Ross L Richardson <rueda@rlr.id.au>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

/*
 * Module providing functions for ASCII Art Big Character representation of
 * strings.  Font is a subset of the "Big" font of the figlet distribution.
 * (All code is original.)
 */

#ifndef _AABC_H_
#define _AABC_H_


#include <stdbool.h>
#include <stddef.h>


#define AABC_FONT_HEIGHT      8
#define AABC_FONT_MAX_WIDTH  15
#define AABC_NO_SMUSH         0
#define AABC_SMUSH            1


/*
 * size_t	 aabc_req_buf_sz_no_smush(const char *s);
 *
 * Returns the maximum buffer size required to hold the big character
 * representation of s (including newlines and terminating NUL).  The
 * actual size required depends on the characters in s and whether
 * "smushing"/kerning is performed.
 *
 * A buffer of size
 *     (strlen(s) * AABC_FONT_MAX_WIDTH + 1) * AABC_FONT_HEIGHT + 1
 * will always be sufficient.
 */
size_t	 aabc_req_buf_sz_no_smush(const char *);


/*
 * void	 aabc_make(const char *s, bool smush, char *buf, size_t buf_sz);
 *
 * If there is (definitely) sufficient space, copies to buf (of size buf_sz)
 * the big character representation of s.  "Smushing"/kerning is performed if
 * and only if smush is true.  If there is insufficient room, buf is set to
 * the empty string.
 */
void	 aabc_make(const char *, bool, char *, size_t);


#endif /* !_AABC_H_ */

==> fwobac-2.1.tar.gz: fwobac-2.1/aabc.h <==
/* $Id: aabc.h,v 1.7 2018/06/19 04:37:31 rlr Exp $ */

/*
 * Copyright (c) 2016, 2018 Ross L Richardson <rueda@rlr.id.au>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

/*
 * Module providing functions for ASCII Art Big Character representation of
 * strings.  Font is a subset of the "Big" font of the figlet distribution.
 * (All code is original.)
 */

#ifndef _AABC_H_
#define _AABC_H_


#include <stdbool.h>
#include <stddef.h>


#define AABC_FONT_HEIGHT      8
#define AABC_FONT_MAX_WIDTH  15
#define AABC_NO_SMUSH         0
#define AABC_SMUSH            1


/*
 * size_t
 * aabc_req_buf_sz_no_smush(const char *s);
 *
 * Returns the maximum buffer size required to hold the big character
 * representation of s (including newlines and terminating NUL).  The
 * actual size required depends on the characters in s and whether
 * "smushing"/kerning is performed.
 *
 * A buffer of size
 *     (strlen(s) * AABC_FONT_MAX_WIDTH + 1) * AABC_FONT_HEIGHT + 1
 * will always be sufficient.
 */
size_t	 aabc_req_buf_sz_no_smush(const char *);


/*
 * void
 * aabc_make(const char *s, bool smush, char *buf, size_t buf_sz);
 *
 * If there is (definitely) sufficient space, copies to buf (of size buf_sz)
 * the big character representation of s.  "Smushing"/kerning is performed if
 * and only if smush is true.  If there is insufficient room, buf is set to
 * the empty string.
 */
void	 aabc_make(const char *, bool, char *, size_t);


#endif /* !_AABC_H_ */
